==> haskell-safe-exceptions-0.1.7.0-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-safe-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 safe-exceptions
version:              0.1.7.0
visibility:           public
id:                   safe-exceptions-0.1.7.0-6tSWxxRd2bM9rx7mFb1Kpz
key:                  safe-exceptions-0.1.7.0-6tSWxxRd2bM9rx7mFb1Kpz
license:              MIT
copyright:            2016 FP Complete
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/safe-exceptions#readme
synopsis:             Safe, consistent, and easy exception handling
description:          Please see README.md
category:             Control
abi:                  dfb4892a08689d3ae640d529ac8a42d2
exposed:              True
exposed-modules:      Control.Exception.Safe
import-dirs:          /usr/lib/ghc-8.8.3/site-local/safe-exceptions-0.1.7.0
library-dirs:         /usr/lib/ghc-8.8.3/site-local/safe-exceptions-0.1.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/safe-exceptions-0.1.7.0
hs-libraries:         HSsafe-exceptions-0.1.7.0-6tSWxxRd2bM9rx7mFb1Kpz
depends:
    base-4.13.0.0 deepseq-1.4.4.0
    exceptions-0.10.4-JUrZHue9S26DL7DmYQK2uL transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-safe-exceptions/html/safe-exceptions.haddock

haddock-html:         /usr/share/doc/haskell-safe-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-safe-exceptions-0.1.7.0-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-safe-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 safe-exceptions
version:              0.1.7.0
visibility:           public
id:                   safe-exceptions-0.1.7.0-1OTAqLq2mgNJRtSmbkyf62
key:                  safe-exceptions-0.1.7.0-1OTAqLq2mgNJRtSmbkyf62
license:              MIT
copyright:            2016 FP Complete
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/safe-exceptions#readme
synopsis:             Safe, consistent, and easy exception handling
description:          Please see README.md
category:             Control
abi:                  8a5f38ef53f7fcac4c1d1b6c1167ffa8
exposed:              True
exposed-modules:      Control.Exception.Safe
import-dirs:          /usr/lib/ghc-8.8.3/site-local/safe-exceptions-0.1.7.0
library-dirs:         /usr/lib/ghc-8.8.3/site-local/safe-exceptions-0.1.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/safe-exceptions-0.1.7.0
hs-libraries:         HSsafe-exceptions-0.1.7.0-1OTAqLq2mgNJRtSmbkyf62
depends:
    base-4.13.0.0 deepseq-1.4.4.0
    exceptions-0.10.4-IWqfFitgKOeJT066q48Qo6 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-safe-exceptions/html/safe-exceptions.haddock

haddock-html:         /usr/share/doc/haskell-safe-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
